#
# spec file for package qt5platform-plugins
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2024 Hillwood Yang <hillwood@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           qt5platform-plugins
Version:        5.6.12
Release:        9.1
Summary:        Qt platform integration plugins
License:        LGPL-3.0-or-later
Group:          Development/Libraries/X11
URL:            https://github.com/linuxdeepin/qt5platform-plugins
Source0:        https://github.com/linuxdeepin/qt5platform-plugins/archive/%{version}/%{name}-%{version}.tar.gz
Patch0:         support-Qt-5_15_8.patch
Patch1:         support-Qt-5_15_9.patch
Patch2:         support-Qt-5_15_10.patch
Patch3:         support-Qt-5_15_11.patch
Patch4:         support-Qt-5_15_12.patch
Patch5:         support-Qt-5_15_13.patch
Patch6:         support-Qt-5_15_14.patch
Patch7:         support-Qt-5_15_15.patch

BuildRequires:  git-core
BuildRequires:  libQt5Core-private-headers-devel
BuildRequires:  libQt5PlatformSupport-private-headers-devel
BuildRequires:  libQt5Widgets-private-headers-devel
BuildRequires:  libqt5-linguist
BuildRequires:  libqt5-qtwayland-private-headers-devel
BuildRequires:  wayland-devel
BuildRequires:  cmake(DWayland)
BuildRequires:  cmake(KF5Wayland)
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5OpenGL)
BuildRequires:  pkgconfig(Qt5WaylandClient)
BuildRequires:  pkgconfig(Qt5X11Extras)
BuildRequires:  pkgconfig(cairo)
BuildRequires:  pkgconfig(dbus-1)
BuildRequires:  pkgconfig(egl)
BuildRequires:  pkgconfig(fontconfig)
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(mtdev)
BuildRequires:  pkgconfig(sm)
BuildRequires:  pkgconfig(udev)
BuildRequires:  pkgconfig(xcb-composite)
BuildRequires:  pkgconfig(xcb-damage)
BuildRequires:  pkgconfig(xcb-icccm)
BuildRequires:  pkgconfig(xcb-image)
BuildRequires:  pkgconfig(xcb-keysyms)
BuildRequires:  pkgconfig(xcb-renderutil)
BuildRequires:  pkgconfig(xcb-util)
BuildRequires:  pkgconfig(xcb-xinerama)
BuildRequires:  pkgconfig(xcb-xkb)
BuildRequires:  pkgconfig(xi)
BuildRequires:  pkgconfig(xkbcommon-x11)
BuildRequires:  pkgconfig(xproto)
BuildRequires:  pkgconfig(xrender)
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
The qt5dxcb-plugin is the Qt platform integration plugin for Deepin Desktop
Environment.

%package -n libqt5-dxcbplugin
Summary:        A Qt platform integration plugin
Group:          Development/Libraries/X11

%description -n libqt5-dxcbplugin
The libqt5-dxcbplugin is the Qt platform dxcbp plugin for Deepin Desktop
Environment.

%package -n libqt5-dwaylandplugin
Summary:        A Qt platform integration plugin
Group:          Development/Libraries/X11

%description -n libqt5-dwaylandplugin
The libqt5-dxcbplugin is the Qt platform dwayland plugin for Deepin Desktop
Environment.

%package -n libqt5-kwayland-shellplugin
Summary:        A Qt platform integration plugin
Group:          Development/Libraries/X11

%description -n libqt5-kwayland-shellplugin
The libqt5-dxcbplugin is the Qt platform kwayland-shell plugin for Deepin Desktop
Environment.

%prep
# %setup -q -a1 -n %{name}-%{version}
%autosetup -p1 -n %{name}-%{version}
if [ "`rpm -q --queryformat '%%{VERSION}' libQt5Core5`" = "5.9.7" ]; then
    cp -r xcb/libqt5xcbqpa-dev/5.9.4 xcb/libqt5xcbqpa-dev/5.9.7
elif [ "`rpm -q --queryformat '%%{VERSION}' libQt5Core5`" = "5.12.7" ]; then
    cp -r xcb/libqt5xcbqpa-dev/5.12.3 xcb/libqt5xcbqpa-dev/5.12.7
fi

# Disable wayland for now: https://github.com/linuxdeepin/qt5platform-plugins/issues/47
# sed -i '/wayland/d' qt5platform-plugins.pro

%build
export Qt_version="`rpm -q --queryformat '%%{VERSION}' libQt5Core5|cut -c 1-6`"
qmake-qt5 DEFINES+=QT_NO_DEBUG_OUTPUT \
          PREFIX=%{_prefix} \
          LIB_INSTALL_DIR=%{_libdir} \
          LIBSUFFIX=%{lib} \
#          CONFIG+=DISABLE_WAYLAND \

%make_build

%install
%qmake5_install

%files -n libqt5-dxcbplugin
%defattr(-,root,root,-)
%doc CHANGELOG.md README.md
%license LICENSE
%dir %{_libdir}/qt5/plugins/platforms/
%{_libdir}/qt5/plugins/platforms/libdxcb.so

%files -n libqt5-dwaylandplugin
%defattr(-,root,root,-)
%doc CHANGELOG.md README.md
%license LICENSE
%dir %{_libdir}/qt5/plugins/platforms/
%{_libdir}/qt5/plugins/platforms/libdwayland.so

%files -n libqt5-kwayland-shellplugin
%defattr(-,root,root,-)
%doc CHANGELOG.md README.md
%license LICENSE
%dir %{_libdir}/qt5/plugins/wayland-shell-integration/
%{_libdir}/qt5/plugins/wayland-shell-integration/libkwayland-shell.so

%changelog
* Wed Sep 11 2024 Hillwood Yang <hillwood@opensuse.org>
- Add support-Qt-5_15_15.patch
* Mon Jun  3 2024 Hillwood Yang <hillwood@opensuse.org>
- Add support-Qt-5_15_14.patch
* Fri Mar 22 2024 Hillwood Yang <hillwood@opensuse.org>
- Add support-Qt-5_15_13.patch to support qt 5.15.13
* Sun Jan  7 2024 Hillwood Yang <hillwood@opensuse.org>
- Add support-Qt-5_15_12.patch
* Sun Dec 10 2023 Hillwood Yang <hillwood@opensuse.org>
- Don't install libudev-mini1 for building
* Sat Nov 18 2023 Hillwood Yang <hillwood@opensuse.org>
- Refrash support-Qt-5_15_11.patch, fix a crash issue.
* Tue Oct 31 2023 Hillwood Yang <hillwood@opensuse.org>
- Add support-Qt-5_15_11.patch, support Qt 5.15.11
* Fri Jun 30 2023 Hillwood Yang <hillwood@opensuse.org>
- Add support-Qt-5_15_10.patch, support Qt 5.15.10
* Tue Jun 13 2023 Hillwood Yang <hillwood@opensuse.org>
- Enable wayland
* Thu Jun  1 2023 Hillwood Yang <hillwood@opensuse.org>
- Refresh support-Qt-5_15_9.patch, fix crash bug
* Wed May 31 2023 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.6.12
  * Fix bugs
* Wed Apr 26 2023 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.6.9
  * load dxcb if XDG_CURRENT_DESKTOP set to DDE
  * Fix bugs
- Add support-Qt-5_15_8.patch and support-Qt-5_15_9.patch
* Fri Apr  7 2023 Max Lin <mlin@suse.com>
- Fix build with Qt 5.15.8+kde185
* Mon Mar 27 2023 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.6.5
  * Add support for 5.15.7
  * Support multi split screen
  * Allow specify include path of qtxcb private headers
- Disable wayland support
* Fri Mar 24 2023 Max Lin <mlin@suse.com>
- Fix build with Qt 5.15.8+kde183
* Wed Jan 18 2023 Hillwood Yang <hillwood@opensuse.org>
- Fix build on Qt 5.15.8
* Sat Dec 24 2022 Hillwood Yang <hillwood@opensuse.org>
- Fix build on Tumbleweed
* Sat Nov 12 2022 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.0.70
  * Change license to LGPL-3.0+
  * Fix bugs
- Fix build on Qt 5.15.7
* Fri Oct  7 2022 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.0.69
  * End the start queue when startid is not used
  * Fix a bug
* Sun Oct  2 2022 Hillwood Yang <hillwood@opensuse.org>
- Fix build on Qt 5.15.6
* Wed Aug 24 2022 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.0.68
  * Support Qt 5.15.5
  * Fix bugs
* Wed Jul  6 2022 Hillwood Yang <hillwood@opensuse.org>
- Fix build on Tumbleweed
* Fri Jul  1 2022 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.0.65
  * Optimize wayland support
  * Fix bugs
* Thu Mar 31 2022 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.0.61
  * Update window property when keepabovechanged
  * Clean up invalid comments and logs
  * ActiveChanged handler changed
  * Add conditional compilation
  * Call sendProperty when setWindowProperty
  * Add global keyboard
  * Fix bugs
* Thu Feb 24 2022 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.0.46
  * Set tooltip role and standalone role
  * Wayland plugin merge from wayland_x86
  * Fix bugs
- Disable wayland plugin, workaround issue#2238
  (https://github.com/linuxdeepin/developer-center/issues/2238)
* Thu Oct 28 2021 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.0.40
  * Add wm class name
  * 2d wallpaper memory shared
  * refactor: Only enable dxcb in dde
  * Fix bugs
* Tue Jul  6 2021 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.0.23
  * Fix bugs
  * Support Qt 5.15.2
* Thu Sep 17 2020 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.0.17
  * Add two new plugins: dwayland and kwayland-shell
* Sat Jan 25 2020 Hillwood Yang <hillwood@opensuse.org>
- Support Qt 5.14.0
* Mon Dec  2 2019 Hillwood Yang <hillwood@opensuse.org>
- Update version to 5.0.1
  * support Qt 5.11.3
  * support signal for DNativeSettings
* Mon Sep 16 2019 Hillwood Yang <hillwood@opensuse.org>
- Support Qt 5.13.1
* Thu Jul 25 2019 Hillwood Yang <hillwood@opensuse.org>
- Update version to 1.2.6
  * Fix clear window blur property if the blur areas/paths is empty
  * Support dynamic create properties for DNativeSettings
  * Support custom use window property for xsettings
  * Fix Immediate ungrab server
  * Add libqt5xcbqpa headers for Qt 5.13.0
  * Fix build failure under Qt 5.13.0
* Wed Jul 10 2019 Hillwood Yang <hillwood@opensuse.org>
- Update version to 1.2.5
  * Support the 16bits/30bits image formats
  * Add new Qt private component for Qt 5.13+
  * Support Qt 15.12.1/15.12.2/15.12.3
  * It is easy to trigger resize when using the touch screen to move the window
  * Fix the window menu cannot hide
  * Fix the foreign platform window screen is wrong
* Mon May 20 2019 Hillwood Yang <hillwood@opensuse.org>
- Update version to 1.2.0
  * Fix DForeignPlatformWindow have a wrong screen object
  * Fix crash at DForeignPlatformWindow::handleConfigureNotifyEvent
  * Fix window can not get focus at mapped
  * do not use methods because symbols are not exported
  * compatibility with Qt 5.12+
- Drop Fix-compilation-under-Qt-5_12_2.patch, Fixed by upstream
* Wed May  8 2019 Hillwood Yang <hillwood@opensuse.org>
- Update qtbase version to 5.12.3 in Tumbleweed.
* Fri Apr 26 2019 Hillwood Yang <hillwood@opensuse.org>
- Fix build for leap15.1
* Sun Apr 21 2019 Hillwood Yang <hillwood@opensuse.org>
- Initial package for version 1.1.26
- Add Fix-compilation-under-Qt-5_12_2.patch, Support qtbase 5.12.2+
